@@ -40,77 +40,78 @@
 #include <itpp/base/algebra/inv.h>
 
 
-namespace itpp {
+namespace itpp
+{
 
 #if defined(HAVE_LAPACK)
 
-  bool inv(const mat &X, mat &Y)
-  {
-    it_assert_debug(X.rows() == X.cols(), "inv: matrix is not square");
+bool inv(const mat &X, mat &Y)
+{
+  it_assert_debug(X.rows() == X.cols(), "inv: matrix is not square");
 
-    int m = X.rows(), info, lwork;
-    lwork = m; // may be choosen better
+  int m = X.rows(), info, lwork;
+  lwork = m; // may be choosen better
 
-    ivec p(m);
-    Y = X;
-    vec work(lwork);
+  ivec p(m);
+  Y = X;
+  vec work(lwork);
 
-    dgetrf_(&m, &m, Y._data(), &m, p._data(), &info); // LU-factorization
-    if (info!=0)
-      return false;
+  dgetrf_(&m, &m, Y._data(), &m, p._data(), &info); // LU-factorization
+  if (info != 0)
+    return false;
 
-    dgetri_(&m, Y._data(), &m, p._data(), work._data(), &lwork, &info);
-    return (info==0);
-  }
+  dgetri_(&m, Y._data(), &m, p._data(), work._data(), &lwork, &info);
+  return (info == 0);
+}
 
-  bool inv(const cmat &X, cmat &Y)
-  {
-    it_assert_debug(X.rows() == X.cols(), "inv: matrix is not square");
+bool inv(const cmat &X, cmat &Y)
+{
+  it_assert_debug(X.rows() == X.cols(), "inv: matrix is not square");
 
-    int m = X.rows(), info, lwork;
-    lwork = m; // may be choosen better
+  int m = X.rows(), info, lwork;
+  lwork = m; // may be choosen better
 
-    ivec p(m);
-    Y = X;
-    cvec work(lwork);
+  ivec p(m);
+  Y = X;
+  cvec work(lwork);
 
-    zgetrf_(&m, &m, Y._data(), &m, p._data(), &info); // LU-factorization
-    if (info!=0)
-      return false;
+  zgetrf_(&m, &m, Y._data(), &m, p._data(), &info); // LU-factorization
+  if (info != 0)
+    return false;
 
-    zgetri_(&m, Y._data(), &m, p._data(), work._data(), &lwork, &info);
-    return (info==0);
-  }
+  zgetri_(&m, Y._data(), &m, p._data(), work._data(), &lwork, &info);
+  return (info == 0);
+}
 
 #else
 
-  bool inv(const mat &X, mat &Y)
-  {
-    it_error("LAPACK library is needed to use inv() function");
-    return false;
-  }
+bool inv(const mat &X, mat &Y)
+{
+  it_error("LAPACK library is needed to use inv() function");
+  return false;
+}
 
-  bool inv(const cmat &X, cmat &Y)
-  {
-    it_error("LAPACK library is needed to use inv() function");
-    return false;
-  }
+bool inv(const cmat &X, cmat &Y)
+{
+  it_error("LAPACK library is needed to use inv() function");
+  return false;
+}
 
 #endif // HAVE_LAPACK
 
-  cmat inv(const cmat &X)
-  {
-    cmat Y;
-    inv(X, Y);
-    return Y;
-  }
+cmat inv(const cmat &X)
+{
+  cmat Y;
+  inv(X, Y);
+  return Y;
+}
 
 
-  mat inv(const mat &X)
-  {
-    mat Y;
-    inv(X, Y);
-    return Y;
-  }
+mat inv(const mat &X)
+{
+  mat Y;
+  inv(X, Y);
+  return Y;
+}
 
 } // namespace itpp
