@@ -40,10 +40,12 @@
 
 //! \cond
 
-namespace blas {
+namespace blas
+{
 
 #ifdef __cplusplus
-extern "C" {
+extern "C"
+{
 #endif /* __cplusplus */
 
   // ----------------------------------------------------------------------
@@ -51,42 +53,42 @@ extern "C" {
   // ----------------------------------------------------------------------
 
   void dswap_(const int *n,
-	      double *x, const int *incx,
-	      double *y, const int *incy);
+              double *x, const int *incx,
+              double *y, const int *incy);
 
   void zswap_(const int *n,
-	      std::complex<double> *x, const int *incx,
-	      std::complex<double> *y, const int *incy);
+              std::complex<double> *x, const int *incx,
+              std::complex<double> *y, const int *incy);
 
   void dscal_(const int *n,
-	      const double *alpha,
-	      double *x, const int *incx);
+              const double *alpha,
+              double *x, const int *incx);
 
   void zscal_(const int *n,
-	      const std::complex<double> *alpha,
-	      std::complex<double> *x, const int *incx);
+              const std::complex<double> *alpha,
+              std::complex<double> *x, const int *incx);
 
   void dcopy_(const int *n,
-	      const double *x, const int *incx,
-	      double *y, const int *incy);
+              const double *x, const int *incx,
+              double *y, const int *incy);
 
   void zcopy_(const int *n,
-	      const std::complex<double> *x, const int *incx,
-	      std::complex<double> *y, const int *incy);
+              const std::complex<double> *x, const int *incx,
+              std::complex<double> *y, const int *incy);
 
   void daxpy_(const int *n,
-	      const double *alpha,
-	      const double *x, const int *incx,
-	      double *y, const int *incy);
+              const double *alpha,
+              const double *x, const int *incx,
+              double *y, const int *incy);
 
   void zaxpy_(const int *n,
-	      const std::complex<double> *alpha,
-	      const std::complex<double> *x, const int *incx,
-	      std::complex<double> *y, const int *incy);
+              const std::complex<double> *alpha,
+              const std::complex<double> *x, const int *incx,
+              std::complex<double> *y, const int *incy);
 
   double ddot_(const int *n,
-	       const double *x, const int *incx,
-	       const double *y, const int *incy);
+               const double *x, const int *incx,
+               const double *y, const int *incy);
 
 #if defined(HAVE_ZDOTUSUB) || defined(HAVE_ZDOTU_VOID)
 #if defined(HAVE_ZDOTU_VOID)
@@ -103,24 +105,24 @@ extern "C" {
   // ----------------------------------------------------------------------
 
   void dgemv_(const char *transA, const int *m, const int *n,
-	      const double *alpha,
-	      const double *A, const int *ldA,
-	      const double *x, const int *incx,
-	      const double *beta,
-	      double *y, const int *incy);
+              const double *alpha,
+              const double *A, const int *ldA,
+              const double *x, const int *incx,
+              const double *beta,
+              double *y, const int *incy);
 
   void zgemv_(const char *transA, const int *m, const int *n,
-	      const std::complex<double> *alpha,
-	      const std::complex<double> *A, const int *ldA,
-	      const std::complex<double> *x, const int *incx,
-	      const std::complex<double> *beta,
-	      std::complex<double> *y, const int *incy);
+              const std::complex<double> *alpha,
+              const std::complex<double> *A, const int *ldA,
+              const std::complex<double> *x, const int *incx,
+              const std::complex<double> *beta,
+              std::complex<double> *y, const int *incy);
 
   void dger_(const int *m, const int *n,
-	     const double *alpha,
-	     const double *x, const int *incx,
-	     const double *y, const int *incy,
-	     double *A, const int *ldA);
+             const double *alpha,
+             const double *x, const int *incx,
+             const double *y, const int *incy,
+             double *A, const int *ldA);
 
   void zgeru_(const int *m, const int *n,
               const std::complex<double> *alpha,
@@ -139,20 +141,20 @@ extern "C" {
   // ----------------------------------------------------------------------
 
   void dgemm_(const char *transA, const char *transB,
-	      const int *m, const int *n, const int *k,
-	      const double *alpha,
-	      const double *A, const int *ldA,
-	      const double *B, const int *ldB,
-	      const double *beta,
-	      double *C, const int *ldC);
+              const int *m, const int *n, const int *k,
+              const double *alpha,
+              const double *A, const int *ldA,
+              const double *B, const int *ldB,
+              const double *beta,
+              double *C, const int *ldC);
 
   void zgemm_(const char *transA, const char *transB,
-	      const int *m, const int *n, const int *k,
-	      const std::complex<double> *alpha,
-	      const std::complex<double> *A, const int *ldA,
-	      const std::complex<double> *B, const int *ldB,
-	      const std::complex<double> *beta,
-	      std::complex<double> *C, const int *ldC);
+              const int *m, const int *n, const int *k,
+              const std::complex<double> *alpha,
+              const std::complex<double> *A, const int *ldA,
+              const std::complex<double> *B, const int *ldB,
+              const std::complex<double> *beta,
+              std::complex<double> *C, const int *ldC);
 
 #ifdef __cplusplus
 }
