@@ -33,55 +33,56 @@
 #include <itpp/base/vec.h>
 
 
-namespace itpp {
+namespace itpp
+{
 
-  /*!
-    \brief Create a polynomial of the given roots
-    \ingroup poly
+/*!
+  \brief Create a polynomial of the given roots
+  \ingroup poly
 
-    Create a polynomial \c p with roots \c r
+  Create a polynomial \c p with roots \c r
 
-    @{
-  */
-  void poly(const vec &r, vec &p);
-  inline vec poly(const vec &r) { vec temp; poly(r, temp); return temp; }
-  void poly(const cvec &r, cvec &p);
-  inline cvec poly(const cvec &r) { cvec temp; poly(r, temp); return temp; }
-  /*! @} */
+  @{
+*/
+void poly(const vec &r, vec &p);
+inline vec poly(const vec &r) { vec temp; poly(r, temp); return temp; }
+void poly(const cvec &r, cvec &p);
+inline cvec poly(const cvec &r) { cvec temp; poly(r, temp); return temp; }
+/*! @} */
 
 
-  /*!
-    \brief Calculate the roots of the polynomial
-    \ingroup poly
+/*!
+  \brief Calculate the roots of the polynomial
+  \ingroup poly
 
-    Calculate the roots \c r of the polynomial \c p
+  Calculate the roots \c r of the polynomial \c p
 
-    @{
-  */
-  void roots(const vec &p, cvec &r);
-  inline cvec roots(const vec &p) { cvec temp; roots(p, temp); return temp; }
-  void roots(const cvec &p, cvec &r);
-  inline cvec roots(const cvec &p) { cvec temp; roots(p, temp); return temp; }
-  /*! @} */
+  @{
+*/
+void roots(const vec &p, cvec &r);
+inline cvec roots(const vec &p) { cvec temp; roots(p, temp); return temp; }
+void roots(const cvec &p, cvec &r);
+inline cvec roots(const cvec &p) { cvec temp; roots(p, temp); return temp; }
+/*! @} */
 
 
-  /*!
-    \brief Evaluate polynomial
-    \ingroup poly
+/*!
+  \brief Evaluate polynomial
+  \ingroup poly
 
-    Evaluate the polynomial \c p (of length \f$N+1\f$ at the points \c x
-    The output is given by
-    \f[
-    p_0 x^N + p_1 x^{N-1} + \ldots + p_{N-1} x + p_N
-    \f]
+  Evaluate the polynomial \c p (of length \f$N+1\f$ at the points \c x
+  The output is given by
+  \f[
+  p_0 x^N + p_1 x^{N-1} + \ldots + p_{N-1} x + p_N
+  \f]
 
-    @{
-  */
-  vec polyval(const vec &p, const vec &x);
-  cvec polyval(const vec &p, const cvec &x);
-  cvec polyval(const cvec &p, const vec &x);
-  cvec polyval(const cvec &p, const cvec &x);
-  /*! @} */
+  @{
+*/
+vec polyval(const vec &p, const vec &x);
+cvec polyval(const vec &p, const cvec &x);
+cvec polyval(const cvec &p, const vec &x);
+cvec polyval(const cvec &p, const cvec &x);
+/*! @} */
 
 } // namespace itpp
 
